#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-conduit
version:              3.0.0.4
visibility:           public
id:                   wai-conduit-3.0.0.4-GscTArXmp4g98ZWSxp3d0d
key:                  wai-conduit-3.0.0.4-GscTArXmp4g98ZWSxp3d0d
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/yesodweb/wai
synopsis:             conduit wrappers for WAI
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-conduit>.

category:             Web, Conduit
abi:                  ed60d6cc6e8573510e4e5e5b81163b16
exposed:              True
exposed-modules:      Network.Wai.Conduit
import-dirs:          /usr/lib/ghc-9.6.6/site-local/wai-conduit-3.0.0.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wai-conduit-3.0.0.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wai-conduit-3.0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-conduit
hs-libraries:         HSwai-conduit-3.0.0.4-GscTArXmp4g98ZWSxp3d0d
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-5Wps0pi1oaaLry3JJy7JDj
    http-types-0.12.4-DIRo50xDRxbE4a3m2IKFXS transformers-0.6.1.0
    wai-3.2.4-G24K6K8Ph5UGm06VtBGtnN

haddock-interfaces:   /usr/share/doc/haskell-wai-conduit/html/wai-conduit.haddock
haddock-html:         /usr/share/doc/haskell-wai-conduit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

